@@ -1,6 +1,6 @@
 package Class::Type::Enum;
 # ABSTRACT: Build Enum-like classes
-$Class::Type::Enum::VERSION = '0.004';
+$Class::Type::Enum::VERSION = '0.005';
 
 use strict;
 use warnings;
@@ -159,7 +159,7 @@ Class::Type::Enum - Build Enum-like classes
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -251,7 +251,7 @@ enum type.  Also works as an instance method for enums of the same class.
 
 =head2 $class->inflate_symbol($symbol)
 
-Does the actual work of L<$class-E<gt>new($value)>, also used when inflating values for
+Does the actual work of C<$class-E<gt>new($value)>, also used when inflating values for
 L<DBIx::Class::InflateColumn::ClassTypeEnum>.
 
 =head2 $class->inflate_ordinal($ord)
@@ -303,7 +303,7 @@ An exception is thrown if an invalid symbol is provided
 
 =head2 $o->is_$value
 
-Shortcut for L<$o-E<gt>is($value)>
+Shortcut for C<$o-E<gt>is($value)>
 
 =head2 $o->stringify
 
